@@ -20,12 +20,12 @@ package handlers
 import (
 	"encoding/json"
 
-	"git.zabbix.com/ap/plugin-support/zbxerr"
 	"go.mongodb.org/mongo-driver/bson"
+	"golang.zabbix.com/sdk/zbxerr"
 )
 
 // ConnPoolStatsHandler
-//https://docs.mongodb.com/manual/reference/command/connPoolStats/#dbcmd.connPoolStats
+// https://docs.mongodb.com/manual/reference/command/connPoolStats/#dbcmd.connPoolStats
 func ConnPoolStatsHandler(s Session, params map[string]string) (interface{}, error) {
 	connPoolStats := &bson.M{}
 	err := s.DB("test").Run(
