@@ -21,7 +21,7 @@ import (
 	"encoding/json"
 	"sort"
 
-	"git.zabbix.com/ap/plugin-support/zbxerr"
+	"golang.zabbix.com/sdk/zbxerr"
 )
 
 type dbEntity struct {
