@@ -18,10 +18,10 @@
 package plugin
 
 import (
-	"git.zabbix.com/ap/mongodb/plugin/handlers"
-	"git.zabbix.com/ap/plugin-support/metric"
-	"git.zabbix.com/ap/plugin-support/plugin"
-	"git.zabbix.com/ap/plugin-support/uri"
+	"golang.zabbix.com/plugin/mongodb/plugin/handlers"
+	"golang.zabbix.com/sdk/metric"
+	"golang.zabbix.com/sdk/plugin"
+	"golang.zabbix.com/sdk/uri"
 )
 
 const (
